@@ -3,7 +3,7 @@
 /* camelMedium.c : Abstract class for a medium
  *
  * Authors: Bertrand Guiheneuf <bertrand@helixcode.com>
- * 	    Michael Zucchi <notzed@ximian.com>
+ *	    Michael Zucchi <notzed@ximian.com>
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
@@ -22,7 +22,6 @@
  * USA
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -40,11 +39,11 @@ static CamelDataWrapperClass *parent_class = NULL;
 #define CM_CLASS(so) CAMEL_MEDIUM_CLASS (CAMEL_OBJECT_GET_CLASS(so))
 
 static gboolean is_offline (CamelDataWrapper *data_wrapper);
-static void add_header (CamelMedium *medium, const char *name,
-			const void *value);
-static void set_header (CamelMedium *medium, const char *name, const void *value);
-static void remove_header (CamelMedium *medium, const char *name);
-static const void *get_header (CamelMedium *medium, const char *name);
+static void add_header (CamelMedium *medium, const gchar *name,
+			gconstpointer value);
+static void set_header (CamelMedium *medium, const gchar *name, gconstpointer value);
+static void remove_header (CamelMedium *medium, const gchar *name);
+static gconstpointer get_header (CamelMedium *medium, const gchar *name);
 
 static GArray *get_headers (CamelMedium *medium);
 static void free_headers (CamelMedium *medium, GArray *headers);
@@ -94,7 +93,6 @@ camel_medium_finalize (CamelObject *object)
 		camel_object_unref (medium->content);
 }
 
-
 CamelType
 camel_medium_get_type (void)
 {
@@ -121,12 +119,11 @@ is_offline (CamelDataWrapper *data_wrapper)
 }
 
 static void
-add_header (CamelMedium *medium, const char *name, const void *value)
+add_header (CamelMedium *medium, const gchar *name, gconstpointer value)
 {
 	g_warning("No %s::add_header implemented, adding %s", camel_type_to_name(CAMEL_OBJECT_GET_TYPE(medium)), name);
 }
 
-
 /**
  * camel_medium_add_header:
  * @medium: a #CamelMedium object
@@ -136,7 +133,7 @@ add_header (CamelMedium *medium, const char *name, const void *value)
  * Adds a header to a #CamelMedium.
  **/
 void
-camel_medium_add_header (CamelMedium *medium, const char *name, const void *value)
+camel_medium_add_header (CamelMedium *medium, const gchar *name, gconstpointer value)
 {
 	g_return_if_fail (CAMEL_IS_MEDIUM (medium));
 	g_return_if_fail (name != NULL);
@@ -146,12 +143,11 @@ camel_medium_add_header (CamelMedium *medium, const char *name, const void *valu
 }
 
 static void
-set_header (CamelMedium *medium, const char *name, const void *value)
+set_header (CamelMedium *medium, const gchar *name, gconstpointer value)
 {
 	g_warning("No %s::set_header implemented, setting %s", camel_type_to_name(CAMEL_OBJECT_GET_TYPE(medium)), name);
 }
 
-
 /**
  * camel_medium_set_header:
  * @medium: a #CamelMedium object
@@ -163,7 +159,7 @@ set_header (CamelMedium *medium, const char *name, const void *value)
  * the header also.
  **/
 void
-camel_medium_set_header (CamelMedium *medium, const char *name, const void *value)
+camel_medium_set_header (CamelMedium *medium, const gchar *name, gconstpointer value)
 {
 	g_return_if_fail (CAMEL_IS_MEDIUM (medium));
 	g_return_if_fail (name != NULL);
@@ -175,12 +171,11 @@ camel_medium_set_header (CamelMedium *medium, const char *name, const void *valu
 }
 
 static void
-remove_header(CamelMedium *medium, const char *name)
+remove_header(CamelMedium *medium, const gchar *name)
 {
 	g_warning("No %s::remove_header implemented, removing %s", camel_type_to_name(CAMEL_OBJECT_GET_TYPE(medium)), name);
 }
 
-
 /**
  * camel_medium_remove_header:
  * @medium: a #CamelMedium
@@ -190,7 +185,7 @@ remove_header(CamelMedium *medium, const char *name)
  * header are removed.
  **/
 void
-camel_medium_remove_header(CamelMedium *medium, const char *name)
+camel_medium_remove_header(CamelMedium *medium, const gchar *name)
 {
 	g_return_if_fail (CAMEL_IS_MEDIUM (medium));
 	g_return_if_fail (name != NULL);
@@ -198,15 +193,13 @@ camel_medium_remove_header(CamelMedium *medium, const char *name)
 	CM_CLASS(medium)->remove_header(medium, name);
 }
 
-
-static const void *
-get_header(CamelMedium *medium, const char *name)
+static gconstpointer
+get_header(CamelMedium *medium, const gchar *name)
 {
 	g_warning("No %s::get_header implemented, getting %s", camel_type_to_name(CAMEL_OBJECT_GET_TYPE(medium)), name);
 	return NULL;
 }
 
-
 /**
  * camel_medium_get_header:
  * @medium: a #CamelMedium object
@@ -219,10 +212,10 @@ get_header(CamelMedium *medium, const char *name)
  * instance of the header.  For multi-occuring headers, use
  * :get_headers().
  *
- * Returns the value of the named header, or %NULL
+ * Returns: the value of the named header, or %NULL
  **/
-const void *
-camel_medium_get_header(CamelMedium *medium, const char *name)
+gconstpointer
+camel_medium_get_header(CamelMedium *medium, const gchar *name)
 {
 	g_return_val_if_fail (CAMEL_IS_MEDIUM (medium), NULL);
 	g_return_val_if_fail (name != NULL, NULL);
@@ -230,7 +223,6 @@ camel_medium_get_header(CamelMedium *medium, const char *name)
 	return CM_CLASS (medium)->get_header (medium, name);
 }
 
-
 static GArray *
 get_headers(CamelMedium *medium)
 {
@@ -247,7 +239,7 @@ get_headers(CamelMedium *medium)
  * to UTF-8 for any headers that are recognized by Camel. The
  * caller should not modify the returned data.
  *
- * Returns the array of headers, which must be freed with
+ * Returns: the array of headers, which must be freed with
  * #camel_medium_free_headers.
  **/
 GArray *
@@ -280,22 +272,20 @@ camel_medium_free_headers (CamelMedium *medium, GArray *headers)
 	CM_CLASS (medium)->free_headers (medium, headers);
 }
 
-
 static CamelDataWrapper *
 get_content_object(CamelMedium *medium)
 {
 	return medium->content;
 }
 
-
 /**
  * camel_medium_get_content_object:
  * @medium: a #CamelMedium object
  *
- * Getss a data wrapper that represents the content of the medium,
+ * Gets a data wrapper that represents the content of the medium,
  * without its headers.
  *
- * Returns a #CamelDataWrapper containing @medium's content
+ * Returns: a #CamelDataWrapper containing @medium's content. Can return NULL.
  **/
 CamelDataWrapper *
 camel_medium_get_content_object (CamelMedium *medium)
@@ -305,7 +295,6 @@ camel_medium_get_content_object (CamelMedium *medium)
 	return CM_CLASS (medium)->get_content_object (medium);
 }
 
-
 static void
 set_content_object (CamelMedium *medium, CamelDataWrapper *content)
 {
@@ -315,7 +304,6 @@ set_content_object (CamelMedium *medium, CamelDataWrapper *content)
 	medium->content = content;
 }
 
-
 /**
  * camel_medium_set_content_object:
  * @medium: a #CamelMedium object
