@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2005 Matt Brown..
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * Authors: Matt Brown <matt@mattb.net.nz>
  *
@@ -33,7 +33,7 @@ G_BEGIN_DECLS
 
 typedef struct _CamelMimeFilterPgp {
 	CamelMimeFilter filter;
-	int state;
+	gint state;
 } CamelMimeFilterPgp;
 
 typedef struct _CamelMimeFilterPgpClass {
