@@ -53,14 +53,14 @@ static CamelTcpStreamClass *parent_class = NULL;
 /* Returns the class for a CamelTcpStreamRaw */
 #define CTSR_CLASS(so) CAMEL_TCP_STREAM_RAW_CLASS (CAMEL_OBJECT_GET_CLASS (so))
 
-static ssize_t stream_read (CamelStream *stream, char *buffer, size_t n);
-static ssize_t stream_write (CamelStream *stream, const char *buffer, size_t n);
-static int stream_flush  (CamelStream *stream);
-static int stream_close  (CamelStream *stream);
+static gssize stream_read (CamelStream *stream, gchar *buffer, gsize n);
+static gssize stream_write (CamelStream *stream, const gchar *buffer, gsize n);
+static gint stream_flush  (CamelStream *stream);
+static gint stream_close  (CamelStream *stream);
 
-static int stream_connect (CamelTcpStream *stream, struct addrinfo *host);
-static int stream_getsockopt (CamelTcpStream *stream, CamelSockOptData *data);
-static int stream_setsockopt (CamelTcpStream *stream, const CamelSockOptData *data);
+static gint stream_connect (CamelTcpStream *stream, struct addrinfo *host);
+static gint stream_getsockopt (CamelTcpStream *stream, CamelSockOptData *data);
+static gint stream_setsockopt (CamelTcpStream *stream, const CamelSockOptData *data);
 static struct sockaddr *stream_get_local_address (CamelTcpStream *stream, socklen_t *len);
 static struct sockaddr *stream_get_remote_address (CamelTcpStream *stream, socklen_t *len);
 
@@ -71,15 +71,15 @@ camel_tcp_stream_raw_class_init (CamelTcpStreamRawClass *camel_tcp_stream_raw_cl
 		CAMEL_TCP_STREAM_CLASS (camel_tcp_stream_raw_class);
 	CamelStreamClass *camel_stream_class =
 		CAMEL_STREAM_CLASS (camel_tcp_stream_raw_class);
-	
+
 	parent_class = CAMEL_TCP_STREAM_CLASS (camel_type_get_global_classfuncs (camel_tcp_stream_get_type ()));
-	
+
 	/* virtual method overload */
 	camel_stream_class->read = stream_read;
 	camel_stream_class->write = stream_write;
 	camel_stream_class->flush = stream_flush;
 	camel_stream_class->close = stream_close;
-	
+
 	camel_tcp_stream_class->connect = stream_connect;
 	camel_tcp_stream_class->getsockopt = stream_getsockopt;
 	camel_tcp_stream_class->setsockopt  = stream_setsockopt;
@@ -91,7 +91,7 @@ static void
 camel_tcp_stream_raw_init (gpointer object, gpointer klass)
 {
 	CamelTcpStreamRaw *stream = CAMEL_TCP_STREAM_RAW (object);
-	
+
 	stream->sockfd = -1;
 }
 
@@ -99,17 +99,16 @@ static void
 camel_tcp_stream_raw_finalize (CamelObject *object)
 {
 	CamelTcpStreamRaw *stream = CAMEL_TCP_STREAM_RAW (object);
-	
+
 	if (stream->sockfd != -1)
 		SOCKET_CLOSE (stream->sockfd);
 }
 
-
 CamelType
 camel_tcp_stream_raw_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register (camel_tcp_stream_get_type (),
 					    "CamelTcpStreamRaw",
@@ -120,23 +119,23 @@ camel_tcp_stream_raw_get_type (void)
 					    (CamelObjectInitFunc) camel_tcp_stream_raw_init,
 					    (CamelObjectFinalizeFunc) camel_tcp_stream_raw_finalize);
 	}
-	
+
 	return type;
 }
 
 #ifdef SIMULATE_FLAKY_NETWORK
-static ssize_t
-flaky_tcp_write (int fd, const char *buffer, size_t buflen)
+static gssize
+flaky_tcp_write (gint fd, const gchar *buffer, gsize buflen)
 {
-	size_t len = buflen;
-	ssize_t nwritten;
-	int val;
-	
+	gsize len = buflen;
+	gssize nwritten;
+	gint val;
+
 	if (buflen == 0)
 		return 0;
-	
-	val = 1 + (int) (10.0 * rand () / (RAND_MAX + 1.0));
-	
+
+	val = 1 + (gint) (10.0 * rand () / (RAND_MAX + 1.0));
+
 	switch (val) {
 	case 1:
 		printf ("flaky_tcp_write (%d, ..., %d): (-1) EINTR\n", fd, buflen);
@@ -153,11 +152,11 @@ flaky_tcp_write (int fd, const char *buffer, size_t buflen)
 	case 4:
 	case 5:
 	case 6:
-		len = 1 + (size_t) (buflen * rand () / (RAND_MAX + 1.0));
+		len = 1 + (gsize) (buflen * rand () / (RAND_MAX + 1.0));
 		len = MIN (len, buflen);
 		/* fall through... */
 	default:
-		printf ("flaky_tcp_write (%d, ..., %d): (%d) '%.*s'", fd, buflen, len, (int) len, buffer);
+		printf ("flaky_tcp_write (%d, ..., %d): (%d) '%.*s'", fd, buflen, len, (gint) len, buffer);
 		nwritten = write (fd, buffer, len);
 		if (nwritten < 0)
 			printf (" errno => %s\n", g_strerror (errno));
@@ -165,25 +164,25 @@ flaky_tcp_write (int fd, const char *buffer, size_t buflen)
 			printf (" only wrote %d bytes\n", nwritten);
 		else
 			printf ("\n");
-		
+
 		return nwritten;
 	}
 }
 
 #define write(fd, buffer, buflen) flaky_tcp_write (fd, buffer, buflen)
 
-static ssize_t
-flaky_tcp_read (int fd, char *buffer, size_t buflen)
+static gssize
+flaky_tcp_read (gint fd, gchar *buffer, gsize buflen)
 {
-	size_t len = buflen;
-	ssize_t nread;
-	int val;
-	
+	gsize len = buflen;
+	gssize nread;
+	gint val;
+
 	if (buflen == 0)
 		return 0;
-	
-	val = 1 + (int) (10.0 * rand () / (RAND_MAX + 1.0));
-	
+
+	val = 1 + (gint) (10.0 * rand () / (RAND_MAX + 1.0));
+
 	switch (val) {
 	case 1:
 		printf ("flaky_tcp_read (%d, ..., %d): (-1) EINTR\n", fd, buflen);
@@ -204,7 +203,7 @@ flaky_tcp_read (int fd, char *buffer, size_t buflen)
 	case 8:
 	case 9:
 	case 10:
-		len = 1 + (size_t) (10.0 * rand () / (RAND_MAX + 1.0));
+		len = 1 + (gsize) (10.0 * rand () / (RAND_MAX + 1.0));
 		len = MIN (len, buflen);
 		/* fall through... */
 	default:
@@ -216,7 +215,7 @@ flaky_tcp_read (int fd, char *buffer, size_t buflen)
 			printf (" only read %d bytes\n", nread);
 		else
 			printf ("\n");
-		
+
 		return nread;
 	}
 }
@@ -225,8 +224,6 @@ flaky_tcp_read (int fd, char *buffer, size_t buflen)
 
 #endif /* SIMULATE_FLAKY_NETWORK */
 
-
-
 /**
  * camel_tcp_stream_raw_new:
  *
@@ -238,61 +235,61 @@ CamelStream *
 camel_tcp_stream_raw_new (void)
 {
 	CamelTcpStreamRaw *stream;
-	
+
 	stream = CAMEL_TCP_STREAM_RAW (camel_object_new (camel_tcp_stream_raw_get_type ()));
-	
+
 	return CAMEL_STREAM (stream);
 }
 
-static ssize_t
-stream_read (CamelStream *stream, char *buffer, size_t n)
+static gssize
+stream_read (CamelStream *stream, gchar *buffer, gsize n)
 {
 	CamelTcpStreamRaw *raw = CAMEL_TCP_STREAM_RAW (stream);
-	
+
 	return camel_read_socket (raw->sockfd, buffer, n);
 }
 
-static ssize_t
-stream_write (CamelStream *stream, const char *buffer, size_t n)
+static gssize
+stream_write (CamelStream *stream, const gchar *buffer, gsize n)
 {
 	CamelTcpStreamRaw *raw = CAMEL_TCP_STREAM_RAW (stream);
-	
+
 	return camel_write_socket (raw->sockfd, buffer, n);
 }
 
-static int
+static gint
 stream_flush (CamelStream *stream)
 {
 	return 0;
 }
 
-static int
+static gint
 stream_close (CamelStream *stream)
 {
 	if (SOCKET_CLOSE (((CamelTcpStreamRaw *)stream)->sockfd) == -1)
 		return -1;
-	
+
 	((CamelTcpStreamRaw *)stream)->sockfd = -1;
 	return 0;
 }
 
 /* this is a 'cancellable' connect, cancellable from camel_operation_cancel etc */
 /* returns -1 & errno == EINTR if the connection was cancelled */
-static int
+static gint
 socket_connect(struct addrinfo *h)
 {
 	struct timeval tv;
 	socklen_t len;
-	int cancel_fd;
-	int errnosav;
-	int ret, fd;
-	
+	gint cancel_fd;
+	gint errnosav;
+	gint ret, fd;
+
 	/* see if we're cancelled yet */
 	if (camel_operation_cancel_check (NULL)) {
 		errno = EINTR;
 		return -1;
 	}
-	
+
 	if (h->ai_socktype != SOCK_STREAM) {
 		errno = EINVAL;
 		return -1;
@@ -300,7 +297,7 @@ socket_connect(struct addrinfo *h)
 
 	if ((fd = socket (h->ai_family, SOCK_STREAM, 0)) == -1)
 		return -1;
-	
+
 	cancel_fd = camel_operation_cancel_fd (NULL);
 	if (cancel_fd == -1) {
 		if (connect (fd, h->ai_addr, h->ai_addrlen) == -1) {
@@ -313,15 +310,15 @@ socket_connect(struct addrinfo *h)
 			errno = errnosav;
 			return -1;
 		}
-		
+
 		return fd;
 	} else {
 #ifndef G_OS_WIN32
-		int flags;
+		gint flags;
 #endif
-		int fdmax, status;
+		gint fdmax, status;
 		fd_set rdset, wrset;
-		
+
 #ifndef G_OS_WIN32
 		flags = fcntl (fd, F_GETFL);
 		fcntl (fd, F_SETFL, flags | O_NONBLOCK);
@@ -342,14 +339,14 @@ socket_connect(struct addrinfo *h)
 #endif
 			return fd;
 		}
-		
+
 		if (!SOCKET_ERROR_IS_EINPROGRESS ()) {
 			errnosav = errno;
 			SOCKET_CLOSE (fd);
 			errno = errnosav;
 			return -1;
 		}
-			
+
 		do {
 			FD_ZERO (&rdset);
 			FD_ZERO (&wrset);
@@ -358,30 +355,30 @@ socket_connect(struct addrinfo *h)
 			fdmax = MAX (fd, cancel_fd) + 1;
 			tv.tv_sec = 60 * 4;
 			tv.tv_usec = 0;
-			
+
 			status = select (fdmax, &rdset, &wrset, NULL, &tv);
 		} while (status == -1 && SOCKET_ERROR_IS_EINTR ());
-		
+
 		if (status <= 0) {
 			SOCKET_CLOSE (fd);
 			errno = ETIMEDOUT;
 			return -1;
 		}
-		
+
 		if (cancel_fd != -1 && FD_ISSET (cancel_fd, &rdset)) {
 			SOCKET_CLOSE (fd);
 			errno = EINTR;
 			return -1;
 		} else {
-			len = sizeof (int);
-			
-			if (getsockopt (fd, SOL_SOCKET, SO_ERROR, (char *) &ret, &len) == -1) {
+			len = sizeof (gint);
+
+			if (getsockopt (fd, SOL_SOCKET, SO_ERROR, (gchar *) &ret, &len) == -1) {
 				errnosav = errno;
 				SOCKET_CLOSE (fd);
 				errno = errnosav;
 				return -1;
 			}
-			
+
 			if (ret != 0) {
 				SOCKET_CLOSE (fd);
 				errno = ret;
@@ -397,15 +394,15 @@ socket_connect(struct addrinfo *h)
 		}
 #endif
 	}
-	
+
 	return fd;
 }
 
-static int
+static gint
 stream_connect (CamelTcpStream *stream, struct addrinfo *host)
 {
 	CamelTcpStreamRaw *raw = CAMEL_TCP_STREAM_RAW (stream);
-	
+
 	g_return_val_if_fail (host != NULL, -1);
 
 	while (host) {
@@ -419,7 +416,7 @@ stream_connect (CamelTcpStream *stream, struct addrinfo *host)
 	return -1;
 }
 
-static int
+static gint
 get_sockopt_level (const CamelSockOptData *data)
 {
 	switch (data->option) {
@@ -431,7 +428,7 @@ get_sockopt_level (const CamelSockOptData *data)
 	}
 }
 
-static int
+static gint
 get_sockopt_optname (const CamelSockOptData *data)
 {
 	switch (data->option) {
@@ -460,55 +457,55 @@ get_sockopt_optname (const CamelSockOptData *data)
 	}
 }
 
-static int
+static gint
 stream_getsockopt (CamelTcpStream *stream, CamelSockOptData *data)
 {
-	int optname, optlen;
-	
+	gint optname, optlen;
+
 	if ((optname = get_sockopt_optname (data)) == -1)
 		return -1;
-	
+
 	if (data->option == CAMEL_SOCKOPT_NONBLOCKING) {
 #ifndef G_OS_WIN32
-		int flags;
-		
+		gint flags;
+
 		flags = fcntl (((CamelTcpStreamRaw *)stream)->sockfd, F_GETFL);
 		if (flags == -1)
 			return -1;
-		
+
 		data->value.non_blocking = flags & O_NONBLOCK ? TRUE : FALSE;
 #else
 		data->value.non_blocking = ((CamelTcpStreamRaw *)stream)->is_nonblocking;
 #endif
 		return 0;
 	}
-	
+
 	return getsockopt (((CamelTcpStreamRaw *)stream)->sockfd,
 			   get_sockopt_level (data),
 			   optname,
-			   (void *) &data->value,
+			   (gpointer) &data->value,
 			   (socklen_t *) &optlen);
 }
 
-static int
+static gint
 stream_setsockopt (CamelTcpStream *stream, const CamelSockOptData *data)
 {
-	int optname;
-	
+	gint optname;
+
 	if ((optname = get_sockopt_optname (data)) == -1)
 		return -1;
-	
+
 	if (data->option == CAMEL_SOCKOPT_NONBLOCKING) {
 #ifndef G_OS_WIN32
-		int flags, set;
-		
+		gint flags, set;
+
 		flags = fcntl (((CamelTcpStreamRaw *)stream)->sockfd, F_GETFL);
 		if (flags == -1)
 			return -1;
-		
+
 		set = data->value.non_blocking ? O_NONBLOCK : 0;
 		flags = (flags & ~O_NONBLOCK) | set;
-		
+
 		if (fcntl (((CamelTcpStreamRaw *)stream)->sockfd, F_SETFL, flags) == -1)
 			return -1;
 #else
@@ -519,11 +516,11 @@ stream_setsockopt (CamelTcpStream *stream, const CamelSockOptData *data)
 #endif
 		return 0;
 	}
-	
+
 	return setsockopt (((CamelTcpStreamRaw *)stream)->sockfd,
 			   get_sockopt_level (data),
 			   optname,
-			   (void *) &data->value,
+			   (gpointer) &data->value,
 			   sizeof (data->value));
 }
 
