@@ -1,5 +1,4 @@
 
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -26,10 +25,10 @@
 
 #define d(x)
 
-static int driver_resp_fetch(CamelIMAPPEngine *ie, guint32 id, CamelIMAPPDriver *sdata);
-static int driver_resp_expunge(CamelIMAPPEngine *ie, guint32 id, CamelIMAPPDriver *sdata);
-static int driver_resp_exists(CamelIMAPPEngine *ie, guint32 id, CamelIMAPPDriver *sdata);
-static int driver_resp_list(CamelIMAPPEngine *ie, guint32 id, CamelIMAPPDriver *sdata);
+static gint driver_resp_fetch(CamelIMAPPEngine *ie, guint32 id, CamelIMAPPDriver *sdata);
+static gint driver_resp_expunge(CamelIMAPPEngine *ie, guint32 id, CamelIMAPPDriver *sdata);
+static gint driver_resp_exists(CamelIMAPPEngine *ie, guint32 id, CamelIMAPPDriver *sdata);
+static gint driver_resp_list(CamelIMAPPEngine *ie, guint32 id, CamelIMAPPDriver *sdata);
 
 static void driver_status(CamelIMAPPEngine *ie, struct _status_info *sinfo, CamelIMAPPDriver *sdata);
 
@@ -73,7 +72,7 @@ camel_imapp_driver_get_type (void)
 			(CamelObjectInitFunc) object_init,
 			(CamelObjectFinalizeFunc) object_finalise);
 	}
-	
+
 	return type;
 }
 
@@ -85,7 +84,7 @@ camel_imapp_driver_new(CamelIMAPPStream *stream)
 
 	driver = CAMEL_IMAPP_DRIVER (camel_object_new (CAMEL_IMAPP_DRIVER_TYPE));
 	ie = driver->engine = camel_imapp_engine_new(stream);
-	
+
 	camel_imapp_engine_add_handler(ie, "FETCH", (CamelIMAPPEngineFunc)driver_resp_fetch, driver);
 	camel_imapp_engine_add_handler(ie, "EXPUNGE", (CamelIMAPPEngineFunc)driver_resp_expunge, driver);
 	camel_imapp_engine_add_handler(ie, "EXISTS", (CamelIMAPPEngineFunc)driver_resp_exists, driver);
@@ -96,14 +95,14 @@ camel_imapp_driver_new(CamelIMAPPStream *stream)
 }
 
 void
-camel_imapp_driver_set_sasl_factory(CamelIMAPPDriver *id, CamelIMAPPSASLFunc get_sasl, void *sasl_data)
+camel_imapp_driver_set_sasl_factory(CamelIMAPPDriver *id, CamelIMAPPSASLFunc get_sasl, gpointer sasl_data)
 {
 	id->get_sasl = get_sasl;
 	id->get_sasl_data = sasl_data;
 }
 
 void
-camel_imapp_driver_set_login_query(CamelIMAPPDriver *id, CamelIMAPPLoginFunc get_login, void *login_data)
+camel_imapp_driver_set_login_query(CamelIMAPPDriver *id, CamelIMAPPLoginFunc get_login, gpointer login_data)
 {
 	id->get_login = get_login;
 	id->get_login_data = login_data;
@@ -127,7 +126,7 @@ camel_imapp_driver_login(CamelIMAPPDriver *id)
 			ic = camel_imapp_engine_command_new(id->engine, "AUTHENTICATE", NULL, "AUTHENTICATE %A", sasl);
 			camel_object_unref(sasl);
 		} else {
-			char *user, *pass;
+			gchar *user, *pass;
 
 			g_assert(id->get_login);
 			id->get_login(id, &user, &pass, id->get_login_data);
@@ -171,7 +170,7 @@ camel_imapp_driver_select(CamelIMAPPDriver *id, struct _CamelIMAPPFolder *folder
 	}
 
 	summary = ((CamelFolder *)folder)->summary;
-	
+
 	ic = camel_imapp_engine_command_new(id->engine, "SELECT", NULL, "SELECT %t", folder->raw_name);
 	camel_imapp_engine_command_queue(id->engine, ic);
 	while (camel_imapp_engine_iterate(id->engine, ic)>0)
@@ -277,7 +276,7 @@ camel_imapp_driver_update(CamelIMAPPDriver *id, CamelIMAPPFolder *folder)
 
 /* FIXME: this is basically a copy of the same in camel-imapp-utils.c */
 static struct {
-	char *name;
+	gchar *name;
 	guint32 flag;
 } flag_table[] = {
 	{ "\\ANSWERED", CAMEL_MESSAGE_ANSWERED },
@@ -311,8 +310,8 @@ imapp_write_flags(CamelIMAPPDriver *id, guint32 orset, gboolean on, CamelFolderS
 
 	count = camel_folder_summary_count(summary);
 	for (j=0;j<sizeof(flag_table)/sizeof(flag_table[0]);j++) {
-		int flush;
-		
+		gint flush;
+
 		if ((orset & flag_table[j].flag) == 0)
 			continue;
 
@@ -330,7 +329,7 @@ imapp_write_flags(CamelIMAPPDriver *id, guint32 orset, gboolean on, CamelFolderS
 				     || (!on && (((flags ^ sflags) & ~flags) & flag_table[j].flag))) {
 					if (ic == NULL)
 						ic = camel_imapp_engine_command_new(id->engine, "STORE", NULL, "UID STORE ");
-					flush = imapp_uidset_add(&ss, ic, camel_message_info_uid(info));				
+					flush = imapp_uidset_add(&ss, ic, camel_message_info_uid(info));
 				}
 				camel_message_info_free((CamelMessageInfo *)info);
 			}
@@ -443,14 +442,14 @@ fetch_data_free(CamelIMAPPFetch *fd)
 }
 #endif
 
-struct _CamelStream *	camel_imapp_driver_fetch(CamelIMAPPDriver *id, struct _CamelIMAPPFolder *folder, const char *uid, const char *body)
+struct _CamelStream *	camel_imapp_driver_fetch(CamelIMAPPDriver *id, struct _CamelIMAPPFolder *folder, const gchar *uid, const gchar *body)
 {
 	return NULL;
 }
 
 #if 0
 void
-camel_imapp_driver_fetch(CamelIMAPPDriver *id, CamelIMAPPFolder *folder, const char *uid, const char *section, CamelIMAPPFetchFunc done, void *data)
+camel_imapp_driver_fetch(CamelIMAPPDriver *id, CamelIMAPPFolder *folder, const gchar *uid, const gchar *section, CamelIMAPPFetchFunc done, gpointer data)
 {
 	struct _fetch_data *fd;
 	CamelIMAPPCommand *ic;
@@ -485,7 +484,7 @@ camel_imapp_driver_fetch(CamelIMAPPDriver *id, CamelIMAPPFolder *folder, const c
 #endif
 
 GPtrArray *
-camel_imapp_driver_list(CamelIMAPPDriver *id, const char *name, guint32 flags)
+camel_imapp_driver_list(CamelIMAPPDriver *id, const gchar *name, guint32 flags)
 {
 	CamelIMAPPCommand * volatile ic;
 	GPtrArray *res;
@@ -512,7 +511,7 @@ camel_imapp_driver_list(CamelIMAPPDriver *id, const char *name, guint32 flags)
 
 			if (id->list_commands) {
 				GSList *top = id->list_commands;
-				
+
 				id->list_commands = top->next;
 				ic = top->data;
 				g_slist_free_1(top);
@@ -522,7 +521,7 @@ camel_imapp_driver_list(CamelIMAPPDriver *id, const char *name, guint32 flags)
 		}
 	} CAMEL_CATCH(e) {
 		GSList *top = id->list_commands;
-		int i;
+		gint i;
 
 		camel_imapp_engine_command_free(id->engine, ic);
 
@@ -552,7 +551,7 @@ camel_imapp_driver_list(CamelIMAPPDriver *id, const char *name, guint32 flags)
 	return res;
 }
 
-static int
+static gint
 driver_resp_list(CamelIMAPPEngine *ie, guint32 idx, CamelIMAPPDriver *id)
 {
 	struct _list_info *linfo;
@@ -565,9 +564,9 @@ driver_resp_list(CamelIMAPPEngine *ie, guint32 idx, CamelIMAPPDriver *id)
 		if ((linfo->flags & CAMEL_FOLDER_NOINFERIORS) == 0
 		    && (id->list_flags & CAMEL_STORE_FOLDER_INFO_RECURSIVE)
 		    && linfo->separator) {
-			int depth = 0;
-			char *p = linfo->name;
-			char c = linfo->separator;
+			gint depth = 0;
+			gchar *p = linfo->name;
+			gchar c = linfo->separator;
 
 			/* this is expensive ... but if we've listed this deep we're going slow anyway */
 			while (*p && depth < 10) {
@@ -579,7 +578,7 @@ driver_resp_list(CamelIMAPPEngine *ie, guint32 idx, CamelIMAPPDriver *id)
 			if (depth < 10
 			    && (linfo->name[0] == 0 || linfo->name[strlen(linfo->name)-1] != c)) {
 				CamelIMAPPCommand *ic;
-				
+
 				ic = camel_imapp_engine_command_new(id->engine, "LIST", NULL, "LIST \"\" %t%c%%", linfo->name, c);
 				id->list_commands = g_slist_prepend(id->list_commands, ic);
 				camel_imapp_engine_command_queue(id->engine, ic);
@@ -601,7 +600,7 @@ static void
 driver_status(CamelIMAPPEngine *ie, struct _status_info *sinfo, CamelIMAPPDriver *sdata)
 {
 	printf("got status response ...\n");
-	switch(sinfo->condition) {
+	switch (sinfo->condition) {
 	case IMAP_READ_WRITE:
 		printf("folder is read-write\n");
 		break;
@@ -611,12 +610,12 @@ driver_status(CamelIMAPPEngine *ie, struct _status_info *sinfo, CamelIMAPPDriver
 	case IMAP_UIDVALIDITY:
 		sdata->uidvalidity = sinfo->u.uidvalidity;
 		break;
-#if 0	
+#if 0
 			/* not defined yet ... */
 	case IMAP_UIDNEXT:
 		printf("got uidnext for folder: %d\n", sinfo->u.uidnext);
 		break;
-#endif	
+#endif
 	case IMAP_UNSEEN:
 		sdata->unseen = sinfo->u.unseen;
 		break;
@@ -634,7 +633,7 @@ driver_status(CamelIMAPPEngine *ie, struct _status_info *sinfo, CamelIMAPPDriver
 	}
 }
 
-static int
+static gint
 driver_resp_exists(CamelIMAPPEngine *ie, guint32 id, CamelIMAPPDriver *sdata)
 {
 	/* should this be an event instead? */
@@ -644,7 +643,7 @@ driver_resp_exists(CamelIMAPPEngine *ie, guint32 id, CamelIMAPPDriver *sdata)
 	return camel_imapp_engine_skip(ie);
 }
 
-static int
+static gint
 driver_resp_expunge(CamelIMAPPEngine *ie, guint32 id, CamelIMAPPDriver *sdata)
 {
 	printf("got expunge response %u\n", id);
@@ -666,12 +665,12 @@ driver_resp_expunge(CamelIMAPPEngine *ie, guint32 id, CamelIMAPPDriver *sdata)
 	return camel_imapp_engine_skip(ie);
 }
 
-static int
+static gint
 driver_resp_fetch(CamelIMAPPEngine *ie, guint32 id, CamelIMAPPDriver *sdata)
 {
 	struct _fetch_info *finfo = NULL;
 	CamelIMAPPMessageInfo *info, *uinfo;
-	unsigned int i;
+	guint i;
 	CamelFolderSummary *summary;
 
 	printf("got fetch response %d\n", id);
@@ -704,13 +703,13 @@ driver_resp_fetch(CamelIMAPPEngine *ie, guint32 id, CamelIMAPPDriver *sdata)
 				printf("inserting new info @ %u\n", i);
 				info->info.uid = g_strdup(finfo->uid);
 			} else {
-				char uidtmp[32];
+				gchar uidtmp[32];
 
 				sprintf(uidtmp, "blank-%u", i);
 				info->info.uid = g_strdup(uidtmp);
 				printf("inserting empty uid %s\n", uidtmp);
 			}
-		
+
 			camel_folder_summary_add(summary, (CamelMessageInfo *)info);
 		}
 		info = (CamelIMAPPMessageInfo *)camel_folder_summary_index(summary, id-1);
@@ -780,7 +779,6 @@ driver_resp_fetch(CamelIMAPPEngine *ie, guint32 id, CamelIMAPPDriver *sdata)
 	return camel_imapp_engine_skip(ie);
 }
 
-
 /* This code is for the separate thread per server idea */
 
 typedef enum {
@@ -802,13 +800,13 @@ struct _CamelIMAPPMsg {
 	union {
 		struct {
 			struct _CamelIMAPPFolder *folder;
-			char *uid;
-			char *section;
+			gchar *uid;
+			gchar *section;
 			struct _CamelStream *body;
 			struct _CamelIMAPPCommand *ic;
 		} fetch;
 		struct {
-			char *name;
+			gchar *name;
 			guint32 flags;
 			GPtrArray *result;
 			GSList *ics;
@@ -818,7 +816,7 @@ struct _CamelIMAPPMsg {
 		} quit;
 		struct {
 			struct _CamelIMAPPFolder *folder;
-			char *search;
+			gchar *search;
 			GPtrArray *results;
 		} search;
 		struct {
@@ -852,11 +850,11 @@ camel_imapp_msg_new(camel_imapp_msg_t type, struct _CamelException *ex, struct _
 	case CAMEL_IMAPP_MSG_FETCH:
 		m->data.fetch.folder = va_arg(ap, struct _CamelIMAPPFolder *);
 		camel_object_ref(m->data.fetch.folder);
-		m->data.fetch.uid = g_strdup(va_arg(ap, char *));
-		m->data.fetch.section = g_strdup(va_arg(ap, char *));
+		m->data.fetch.uid = g_strdup(va_arg(ap, gchar *));
+		m->data.fetch.section = g_strdup(va_arg(ap, gchar *));
 		break;
 	case CAMEL_IMAPP_MSG_LIST:
-		m->data.list.name = g_strdup(va_arg(ap, char *));
+		m->data.list.name = g_strdup(va_arg(ap, gchar *));
 		m->data.list.flags = va_arg(ap, guint32);
 		break;
 	case CAMEL_IMAPP_MSG_QUIT:
@@ -865,7 +863,7 @@ camel_imapp_msg_new(camel_imapp_msg_t type, struct _CamelException *ex, struct _
 	case CAMEL_IMAPP_MSG_SEARCH:
 		m->data.search.folder = va_arg(ap, struct _CamelIMAPPFolder *);
 		camel_object_ref(m->data.search.folder);
-		m->data.search.search = g_strdup(va_arg(ap, char *));
+		m->data.search.search = g_strdup(va_arg(ap, gchar *));
 		break;
 	case CAMEL_IMAPP_MSG_SYNC:
 		m->data.sync.folder = va_arg(ap, struct _CamelIMAPPFolder *);
@@ -925,7 +923,7 @@ void
 camel_imapp_driver_worker(CamelIMAPPDriver *id)
 {
 	CamelIMAPPMsg *m;
-	int go = TRUE;
+	gint go = TRUE;
 
 	do {
 		/*m = (CamelIMAPPMsg *)camel_msgport_try_pop(id->queue);*/
