@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -41,8 +41,6 @@
 
 G_DEFINE_TYPE (ENameSelectorList, e_name_selector_list, E_TYPE_NAME_SELECTOR_ENTRY)
 
-static void e_name_selector_list_class_init (ENameSelectorListClass *name_selector_list_class);
-static void e_name_selector_list_init       (ENameSelectorList *name_selector_list);
 static void e_name_selector_list_dispose    (GObject *object);
 static void e_name_selector_list_finalize   (GObject *object);
 
@@ -51,7 +49,7 @@ static void e_name_selector_list_finalize   (GObject *object);
 static void
 enl_popup_size (ENameSelectorList *list)
 {
-	int height = 0, count;
+	gint height = 0, count;
 	GtkTreeViewColumn *column = NULL;
 
 	column = gtk_tree_view_get_column ( GTK_TREE_VIEW (list->tree_view), 0);
@@ -72,7 +70,7 @@ static void
 enl_popup_position (ENameSelectorList *list)
 {
 	GdkWindow *window;
-	int x,y;
+	gint x,y;
 
 	enl_popup_size (list);
 	window = gtk_widget_get_window (GTK_WIDGET (list));
@@ -86,19 +84,19 @@ static void
 enl_popup_grab (ENameSelectorList *list)
 {
 	GdkWindow *window;
-	int len;
+	gint len;
 
 	window = gtk_widget_get_window (GTK_WIDGET (list->popup));
 
 	gtk_grab_add (GTK_WIDGET (list->popup));
 
 	gdk_pointer_grab (window, TRUE,
-                    	  GDK_BUTTON_PRESS_MASK |
-                    	  GDK_BUTTON_RELEASE_MASK |
-                    	  GDK_POINTER_MOTION_MASK,
-                	  NULL, NULL, GDK_CURRENT_TIME);
+			  GDK_BUTTON_PRESS_MASK |
+			  GDK_BUTTON_RELEASE_MASK |
+			  GDK_POINTER_MOTION_MASK,
+			  NULL, NULL, GDK_CURRENT_TIME);
 
-    	gdk_keyboard_grab (window, TRUE, GDK_CURRENT_TIME);
+	gdk_keyboard_grab (window, TRUE, GDK_CURRENT_TIME);
 	gtk_widget_grab_focus ((GtkWidget *)list);
 
 	/* Build the listview from the model */
@@ -123,7 +121,7 @@ enl_popup_ungrab (ENameSelectorList *list)
 static gboolean
 enl_entry_focus_in (ENameSelectorList *list, GdkEventFocus *event, gpointer dummy)
 {
-	int len;
+	gint len;
 
 	/* FIXME: Dont select every thing by default- Code is there but still it does */
 	len = strlen(gtk_entry_get_text(GTK_ENTRY(list)));
@@ -175,14 +173,14 @@ enl_popup_enter_notify (GtkWidget        *widget,
 			ENameSelectorList *list)
 {
   if (event->type == GDK_ENTER_NOTIFY && !GTK_WIDGET_HAS_GRAB (list->popup))
-  	enl_popup_grab (list);
+	enl_popup_grab (list);
 
   return TRUE;
 }
 
 static void
 enl_tree_select_node (ENameSelectorList *list,
-		      int n)
+		      gint n)
 {
 	GtkTreeSelection *selection;
 	GtkTreeIter iter;
@@ -225,11 +223,11 @@ static void
 delete_row (GtkTreePath *path, ENameSelectorList *list)
 {
 	GtkTreeIter   iter;
-	int n, len;
+	gint n, len;
 	GtkTreeSelection *selection;
 
 	if (!gtk_tree_model_get_iter (GTK_TREE_MODEL (E_NAME_SELECTOR_ENTRY (list)->destination_store), &iter, path))
-      		return;
+		return;
 
 	selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW (list->tree_view));
 	len = e_destination_store_get_destination_count (E_NAME_SELECTOR_ENTRY (list)->destination_store);
@@ -244,10 +242,10 @@ delete_row (GtkTreePath *path, ENameSelectorList *list)
 	/* We deleted the last entry */
 	if (len == 1) {
 		enl_popup_ungrab (list);
-		if(list->menu)
+		if (list->menu)
 			gtk_menu_popdown(GTK_MENU (list->menu));
 		gtk_widget_hide ( GTK_WIDGET (list->popup));
-	    	return;
+		return;
 	}
 
 	iter.stamp = ((ENameSelectorEntry *) list)->destination_store->stamp;
@@ -261,7 +259,6 @@ delete_row (GtkTreePath *path, ENameSelectorList *list)
 	list->rows = e_destination_store_get_destination_count (((ENameSelectorEntry *) list)->destination_store);
 	enl_popup_size (list);
 
-
 }
 
 static void
@@ -307,10 +304,10 @@ destination_set_list (GtkWidget *item, EDestination *destination)
 static void
 destination_set_email (GtkWidget *item, EDestination *destination)
 {
-	int email_num;
+	gint email_num;
 	EContact *contact;
 
- 	if (!gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (item)))
+	if (!gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (item)))
 		return;
 	contact = e_destination_get_contact (destination);
 	if (!contact)
@@ -350,9 +347,9 @@ enl_tree_button_press_event (GtkWidget *widget,
 	GtkWidget    *menu_item;
 	GList        *email_list = NULL, *l;
 	gint          i;
-	int 	      email_num, len;
-	char         *delete_label;
-	GSList 	     *group = NULL;
+	gint	      email_num, len;
+	gchar         *delete_label;
+	GSList	     *group = NULL;
 	gboolean      is_list;
 	gboolean      show_menu = FALSE;
 	GtkTreeSelection *selection;
@@ -360,8 +357,8 @@ enl_tree_button_press_event (GtkWidget *widget,
 	PopupDeleteRowInfo *row_info;
 	GtkTreeIter   iter;
 
-  	if ( !GTK_WIDGET_HAS_GRAB (list->popup))
-        	enl_popup_grab (list);
+	if ( !GTK_WIDGET_HAS_GRAB (list->popup))
+		enl_popup_grab (list);
 
 	gtk_tree_view_get_dest_row_at_pos(GTK_TREE_VIEW (list->tree_view), event->x, event->y, &path, NULL);
 	selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW (list->tree_view));
@@ -401,11 +398,11 @@ enl_tree_button_press_event (GtkWidget *widget,
 	if (is_list) {
 		const GList *dests = e_destination_list_get_dests (destination);
 		GList *iters;
-		int length = g_list_length ((GList *)dests);
+		gint length = g_list_length ((GList *)dests);
 
 		for (iters = (GList *)dests; iters; iters = iters->next) {
 			EDestination *dest = (EDestination *) iters->data;
-			const char *email = e_destination_get_email (dest);
+			const gchar *email = e_destination_get_email (dest);
 
 			if (!email || *email == '\0')
 				continue;
@@ -469,7 +466,7 @@ enl_tree_button_press_event (GtkWidget *widget,
 		gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), menu_item);
 	}
 
-	delete_label = g_strdup_printf(_("_Delete %s"), (char *)e_contact_get_const (contact, E_CONTACT_FILE_AS));
+	delete_label = g_strdup_printf(_("_Delete %s"), (gchar *)e_contact_get_const (contact, E_CONTACT_FILE_AS));
 	menu_item = gtk_menu_item_new_with_mnemonic (delete_label);
 	g_free (delete_label);
 	gtk_widget_show (menu_item);
@@ -484,7 +481,6 @@ enl_tree_button_press_event (GtkWidget *widget,
 
 	return TRUE;
 
-
 }
 
 static gboolean
@@ -507,7 +503,7 @@ enl_tree_key_press_event (GtkWidget *w,
 		g_list_free (paths);
 	} else if (event->keyval != GDK_Up && event->keyval != GDK_Down
 		   && event->keyval != GDK_Shift_R && event->keyval != GDK_Shift_L
-		   && event->keyval != GDK_Control_R && event->keyval != GDK_Control_L){
+		   && event->keyval != GDK_Control_R && event->keyval != GDK_Control_L) {
 
 		enl_popup_ungrab (list);
 		gtk_widget_hide ( GTK_WIDGET (list->popup));
@@ -532,7 +528,7 @@ e_name_selector_list_expand_clicked(ENameSelectorList *list)
 	}
 	else {
 		enl_popup_ungrab (list);
-		if(list->menu)
+		if (list->menu)
 			gtk_menu_popdown(GTK_MENU (list->menu));
 		gtk_widget_hide (GTK_WIDGET (list->popup));
 	}
@@ -611,20 +607,20 @@ e_name_selector_list_init (ENameSelectorList *list)
 
 	scroll = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
-                                	GTK_POLICY_NEVER,
+					GTK_POLICY_NEVER,
 					GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scroll),
-                                       	     GTK_SHADOW_NONE);
+					     GTK_SHADOW_NONE);
 	gtk_widget_set_size_request (
 		gtk_scrolled_window_get_vscrollbar (
 		GTK_SCROLLED_WINDOW (scroll)), -1, 0);
 
 	list->popup =  GTK_WINDOW (gtk_window_new (GTK_WINDOW_POPUP));
- 	gtk_window_set_resizable (GTK_WINDOW (list->popup), FALSE);
+	gtk_window_set_resizable (GTK_WINDOW (list->popup), FALSE);
 
 	popup_frame = gtk_frame_new (NULL);
 	gtk_frame_set_shadow_type (GTK_FRAME (popup_frame),
-			     	   GTK_SHADOW_ETCHED_IN);
+				   GTK_SHADOW_ETCHED_IN);
 
 	gtk_container_add (GTK_CONTAINER (list->popup), popup_frame);
 
@@ -633,7 +629,7 @@ e_name_selector_list_init (ENameSelectorList *list)
 
 	gtk_container_add (GTK_CONTAINER (scroll), list->tree_view);
 	gtk_box_pack_start (GTK_BOX (vbox), scroll,
-                      	    TRUE, TRUE, 0);
+			    TRUE, TRUE, 0);
 
 	g_signal_connect_after (GTK_WIDGET (list), "focus-in-event", G_CALLBACK(enl_entry_focus_in), NULL);
 	g_signal_connect (GTK_WIDGET (list), "focus-out-event", G_CALLBACK(enl_entry_focus_out), NULL);
