@@ -1,10 +1,10 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Authors :
- *  Ebby Wiselyn <ebbywiselyn@gmail.com>
+ *  Ebby Wiselyn <ebbyw@gnome.org>
  *  Jason Willis <zenbrother@gmail.com>
  *
- * Copyright 2007, Novell, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -28,17 +28,14 @@
 #include <glib.h>
 #include <glib-object.h>
 
-
 /* LibXML2 includes */
 #include <libxml/parser.h>
 #include <libxml/tree.h>
 #include <libxml/xpath.h>
 #include <libxml/xpathInternals.h>
 
-
 G_BEGIN_DECLS
 
-
 #define GDATA_TYPE_ENTRY           (gdata_entry_get_type())
 #define GDATA_ENTRY(obj)           (G_TYPE_CHECK_INSTANCE_CAST((obj), GDATA_TYPE_ENTRY, GDataEntry))
 #define GDATA_ENTRY_CLASS(klass)   (G_TYPE_CHECK_CLASS_CAST((klass), GDATA_TYPE_ENTRY, GDataEntryClass))
@@ -50,7 +47,6 @@ typedef struct _GDataEntry GDataEntry;
 typedef struct _GDataEntryClass GDataEntryClass;
 typedef struct _GDataEntryPrivate GDataEntryPrivate;
 
-
 struct _GDataEntry {
 
   GObject parent;
@@ -76,8 +72,75 @@ struct _Attendee {
 	gchar *attendee_type;
 };
 
-GType gdata_entry_get_type(void);
+typedef struct _GDataEntryAuthor GDataEntryAuthor;
+struct _GDataEntryAuthor {
+	gchar *email;
+	gchar *name;
+	gchar *uri;
+};
 
+typedef struct _GDataEntryCategory GDataEntryCategory;
+struct _GDataEntryCategory {
+	gchar *label;
+	gchar *scheme;
+	gchar *scheme_prefix;
+	gchar *scheme_suffix;
+	gchar *term;
+};
+
+typedef struct _GDataEntryLink GDataEntryLink;
+struct _GDataEntryLink {
+	gchar *href;
+	gint  length;
+	gchar *rel;
+	gchar *title;
+	gchar *type;
+};
+
+typedef struct _GDataEntryEmailAddress GDataEntryEmailAddress;
+struct _GDataEntryEmailAddress {
+	gchar *address;
+	gchar *label;
+	gchar *rel;
+	gboolean primary;
+};
+
+typedef struct _GDataEntryIMAddress GDataEntryIMAddress;
+struct _GDataEntryIMAddress {
+	gchar *address;
+	gchar *label;
+	gchar *rel;
+	gchar *protocol;
+	gboolean primary;
+};
+
+typedef struct _GDataEntryOrganization GDataEntryOrganization;
+struct _GDataEntryOrganization {
+	gchar *name;
+	gchar *title;
+	gchar *label;
+	gchar *rel;
+	gboolean primary;
+};
+
+typedef struct _GDataEntryPhoneNumber GDataEntryPhoneNumber;
+struct _GDataEntryPhoneNumber {
+	gchar *number;
+	gchar *uri;
+	gchar *label;
+	gchar *rel;
+	gboolean primary;
+};
+
+typedef struct _GDataEntryPostalAddress GDataEntryPostalAddress;
+struct _GDataEntryPostalAddress {
+	gchar *address;
+	gchar *label;
+	gchar *rel;
+	gboolean primary;
+};
+
+GType gdata_entry_get_type(void);
 
 /***** API  *****/
 
@@ -121,17 +184,20 @@ gchar * gdata_entry_get_start_date (GDataEntry *entry);
 
 gchar * gdata_entry_get_end_date (GDataEntry *entry);
 
-gchar *
-gdata_entry_get_visibility (GDataEntry *entry);
+gchar * gdata_entry_get_visibility (GDataEntry *entry);
 
-gchar *
-gdata_entry_get_transparency (GDataEntry *entry);
+gchar * gdata_entry_get_transparency (GDataEntry *entry);
 
-GSList *
-gdata_entry_get_attendee_list (GDataEntry *entry);
+GSList * gdata_entry_get_attendee_list (GDataEntry *entry);
+
+GSList * gdata_entries_new_from_xml (const gchar *feedXML, const gint length);
+
+gboolean gdata_entry_is_recurrent (GDataEntry *entry);
 
 void gdata_entry_set_author (GDataEntry *entry, GSList *author);
 
+void gdata_entry_set_phone_numbers (GDataEntry *entry, GSList *phone_numbers);
+
 void gdata_entry_set_categories (GDataEntry *entry, GSList *categories);
 
 void gdata_entry_set_title (GDataEntry *entry, const gchar *title);
@@ -158,18 +224,42 @@ void gdata_entry_create_authors (GDataEntry *entry,const gchar *name, const gcha
 
 void gdata_entry_create_categories (GDataEntry *entry, const gchar *scheme, const gchar *label , const gchar *term);
 
-GSList * gdata_entries_new_from_xml (const gchar *feedXML, const gint length);
+void gdata_entry_set_id (GDataEntry *entry, gchar *id);
 
-void
-gdata_entry_set_id (GDataEntry *entry, gchar *id);
+void  gdata_entry_set_email_addresses (GDataEntry *entry, GSList *emails);
 
-gboolean gdata_entry_is_recurrent (GDataEntry *entry);
+void  gdata_entry_set_im_addresses (GDataEntry *entry, GSList *ims);
+
+void  gdata_entry_set_organizations (GDataEntry *entry, GSList *orgs);
+
+void  gdata_entry_set_postal_addresses (GDataEntry *entry, GSList *pas);
+
+void gdata_entry_set_attendee_list (GDataEntry *entry, GSList *attendee);
+
+gboolean gdata_entry_is_deleted (GDataEntry *entry);
+
+GSList * gdata_entry_get_email_addresses (GDataEntry *entry);
+
+GSList * gdata_entry_get_im_addresses (GDataEntry *entry);
+
+GSList * gdata_entry_get_organizations (GDataEntry *entry);
+
+GSList * gdata_entry_get_phone_numbers (GDataEntry *entry);
+
+GSList * gdata_entry_get_postal_addresses (GDataEntry *entry);
+
+GDataEntryEmailAddress * gdata_entry_get_primary_email_address (GDataEntry *entry);
+
+GDataEntryIMAddress * gdata_entry_get_primary_im_address (GDataEntry *entry);
+
+GDataEntryOrganization * gdata_entry_get_primary_organization (GDataEntry *entry);
+
+GDataEntryPhoneNumber * gdata_entry_get_primary_phone_number (GDataEntry *entry);
+
+GDataEntryPostalAddress * gdata_entry_get_primary_postal_address (GDataEntry *entry);
+
+const gchar *gdata_entry_get_custom (GDataEntry *entry, const gchar *name);
+void gdata_entry_set_custom (GDataEntry *entry, const gchar *name, const gchar *value);
 
-void
-gdata_entry_set_attendee_list (GDataEntry *entry, GSList *attendee);
 #endif
 
-
-
-
-
